@@ -84,34 +84,7 @@ class {package_name}Conan(Sense2File):
         self.copy("*.so", dst="lib", keep_path=False)
         self.copy("*.a", dst="lib", keep_path=False)
         self.copy("*", dst="bin", src="bin")
-
-    # def package_info(self):
-    #    self.cpp_info.libs = ["hello"]
         
-    def deb(self):
-        ## copy *.deb to deb folder
-        package_name = self.name
-        package_version = self.version
-        deb_file = package_name + "_" + package_version + ".deb"
-        self.copy(deb_file, dst=".", keep_path=False)
-
-        if os.path.exists(package_name):
-            self.run("rm -rf " + package_name)
-        
-        self.run("rm -rf *.deb")
-        pass
-        
-    def install_deb(self):
-        print("run conanfile install_deb")
-        pass
-    
-    def install_docker(self):
-        print("run conanfile install_docker")
-        pass
-
-    def install_sense_system(self):
-        print("run conanfile install_sense_system")
-        pass
 """
 
 
