@@ -137,12 +137,19 @@ def _create_deb_file(conanfile):
 
     ## copy *.deb in package folder to deb folder
     conanfile.copy(deb_file, dst=".", keep_path=False)
-    output.success("copy '%s' to deb folder" % deb_file)
+    output.success("copy deb_file '%s' to deb folder" % deb_file)
     
     ## clean package folder
     if os.path.exists(deb_folder):
             conanfile.run("rm -rf " + deb_folder)
+    else:
+        msg = "deb_folde '%s' is not existed. \
+                Check deb_folder is generated correctly." % (deb_folder)
+        output.warn(msg)       
 
     if os.path.exists(deb_file):
         conanfile.run("rm -rf " + deb_file)
-    
\ No newline at end of file
+    else:
+        msg = "deb_file '%s' is not existed. \
+                Check deb_file is generated correctly." % (deb_file)
+        output.warn(msg)
